[tor-commits] [tor-browser/tor-browser-85.0-10.0-1] Bug 1688017 - Disable webrender on Mali-G76 devices. r=nical, geckoview-reviewers, agi, a=jcristau

sysrqb at torproject.org sysrqb at torproject.org
Tue Feb 2 23:24:26 UTC 2021


commit 6b8b7b5402dfe2051c879aa152d48d37d0b35dc7
Author: Jamie Nicol <jnicol at mozilla.com>
Date:   Mon Jan 25 15:37:31 2021 +0000

    Bug 1688017 - Disable webrender on Mali-G76 devices. r=nical,geckoview-reviewers,agi, a=jcristau
    
    We're seeing reports of crashes when users attempt to watch video on
    Mali-G76 devices. Disable webrender for now on Mali-G76 until the
    underlying problem is identified and fixed.
    
    Differential Revision: https://phabricator.services.mozilla.com/D102903
---
 widget/android/GfxInfo.cpp | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/widget/android/GfxInfo.cpp b/widget/android/GfxInfo.cpp
index 6c69e55bab1c..eec3db83aba1 100644
--- a/widget/android/GfxInfo.cpp
+++ b/widget/android/GfxInfo.cpp
@@ -591,8 +591,10 @@ nsresult GfxInfo::GetFeatureStatusImpl(
       // Enable Webrender on all Adreno 6xx devices
       isUnblocked |= gpu.Find("Adreno (TM) 6", /*ignoreCase*/ true) >= 0;
 
-      // Enable Webrender on all Mali-Gxx GPUs
-      isUnblocked |= gpu.Find("Mali-G", /*ignoreCase*/ true) >= 0;
+      // Enable Webrender on all Mali-Gxx GPUs, excluding G76 due to bug
+      // 1688017.
+      isUnblocked |= gpu.Find("Mali-G", /*ignoreCase*/ true) >= 0 &&
+                     gpu.Find("Mali-G76", /*ignoreCase*/ true) == kNotFound;
 
       if (!isUnblocked) {
         *aStatus = nsIGfxInfo::FEATURE_BLOCKED_DEVICE;



More information about the tor-commits mailing list